@@ -1,4 +1,3 @@
-
 #
 # BioPerl module for Bio::DB::GenPept
 #
@@ -42,9 +41,9 @@ and other Bioperl modules. Send your comments and suggestions preferably
  to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-  vsns-bcd-perl@lists.uni-bielefeld.de          - General discussion
-  vsns-bcd-perl-guts@lists.uni-bielefeld.de     - Technically-oriented discussion
-  http://bio.perl.org/MailList.html             - About the mailing lists
+   bioperl-l@bioperl.org             - General discussion
+   bioperl-guts-l@bioperl.org        - Automated bug and CVS messages
+   http://bioperl.org/MailList.shtml - About the mailing lists
 
 =head2 Reporting Bugs
 
@@ -76,6 +75,7 @@ use vars qw(@ISA);
 use Bio::DB::RandomAccessI;
 use Bio::SeqIO;
 use IO::Socket;
+use IO::File;
 
 @ISA = qw(Bio::Root::Object Bio::DB::RandomAccessI);
 
@@ -144,7 +144,6 @@ sub get_Seq_by_acc {
   Args    : $ref : a reference to an array of unique identifiers for
                    the desired sequence entries
 
-
 =cut
 
 sub get_Stream_by_id {
@@ -190,8 +189,7 @@ sub get_Stream_by_acc {
   Example :
   Returns : a Bio::SeqIO stream object
   Args    : $ref : either an array reference, a filename, or a filehandle
-            from which to get the list of unique id's/accession numbers.
-
+            from which to get the list of unique ids/accession numbers.
 
 =cut
 
@@ -209,11 +207,15 @@ sub get_Stream_by_batch {
        seek $fh, 0, 0;
        $filename = "tempfile.txt";
    } elsif ( $which eq '') { # $ref is a filename
-       $fh = new IO::File $ref, "r";
+       $fh = IO::File->new($ref, "r") || 
+	   $self->throw("file $ref does not exist or is not readable");
+
        $filename = $ref;
    } elsif ( $which eq 'GLOB' or $which eq 'IO::File') { # $ref is assumed to be a filehandle
        $fh = $ref;
        $filename = "tempfile.txt";
+   } else {
+       $self->throw("tream by batch did not get a valid argument\n");
    }
 
    my $wwwbuf = "DB=n&REQUEST_TYPE=LIST_OF_GIS&FORMAT=1&HTML=FALSE&SAVETO=FALSE&NOHEADER=TRUE&UID=" . join(',', grep { chomp; } <$fh> );
@@ -291,18 +293,3 @@ sub _get_sock {
 1;
 __END__
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
