@@ -1,4 +1,3 @@
-
 #
 # BioPerl module for Bio::LocatableSeq
 #
@@ -42,7 +41,6 @@ used.
 
 Please post to the guts list for more about this, or contact Ewan Birney.
 
-
 =head1 CONTACT
 
 Ewan Birney <birney@ebi.ac.uk>
@@ -53,10 +51,8 @@ The rest of the documentation details each of the object methods. Internal metho
 
 =cut
 
-
 # Let the code begin...
 
-
 package Bio::LocatableSeq;
 use vars qw(@ISA);
 use strict;
@@ -68,8 +64,6 @@ use Bio::RangeI;
 
 use Bio::Root::Object;
 
-
-
 @ISA = qw(Bio::Seq Bio::RangeI);
 
 # new() is inherited from Bio::Root::Object
@@ -98,7 +92,6 @@ sub _initialize {
  Returns : value of start
  Args    : newvalue (optional)
 
-
 =cut
 
 sub start{
@@ -119,7 +112,6 @@ sub start{
  Returns : value of end
  Args    : newvalue (optional)
 
-
 =cut
 
 sub end{
@@ -140,7 +132,6 @@ sub end{
  Returns : value of strand
  Args    : newvalue (optional)
 
-
 =cut
 
 sub strand{
@@ -162,17 +153,15 @@ sub strand{
  Returns : 
  Args    :
 
-
 =cut
 
 sub get_nse{
-   my ($self) = @_;
+   my ($self,$char1,$char2) = @_;
   
-   return $self->id() . "/" . $self->start . "-" . $self->end ;
+   if( !defined $char1 ) { $char1 = "/"; }
+   if( !defined $char2 ) { $char2 = "-"; }
+
+   return $self->id() . $char1 . $self->start . $char2 . $self->end ;
 
 }
 
-
-
-
-
