@@ -2,7 +2,7 @@
 # PACKAGE : Bio::Root::IOManager.pm
 # AUTHOR  : Steve A. Chervitz (sac@genome.stanford.edu)
 # CREATED : 26 Mar 1997
-# REVISION: $Id: IOManager.pm,v 1.5 1999/04/06 11:14:11 sac Exp $
+# REVISION: $Id: IOManager.pm,v 1.6.2.1 2000/09/15 08:24:18 jgrg Exp $
 # STATUS  : Alpha
 #            
 # For documentation, run this module through pod2html 
@@ -10,7 +10,7 @@
 #
 # MODIFICATION NOTES: See bottom of file.
 #
-# Copyright (c) 1997-8 Steve A. Chervitz. All Rights Reserved.
+# Copyright (c) 1997-2000 Steve A. Chervitz. All Rights Reserved.
 #           This module is free software; you can redistribute it and/or 
 #           modify it under the same terms as Perl itself.
 #-----------------------------------------------------------------------------
@@ -47,7 +47,6 @@ which delegates various I/O tasks to this module.
     $myIO = new Bio::Root::IOManager(-WHERE   =>'/usr/tmp/data.out', 
    				     -PARENT =>$self);
 
-
 =head1 INSTALLATION
 
 This module is included with the central Bioperl distribution:
@@ -57,7 +56,6 @@ This module is included with the central Bioperl distribution:
 
 Follow the installation instructions included in the README file.
 
-
 =head1 DESCRIPTION
 
 This module encapsulates the data and methods necessary for regulating 
@@ -90,7 +88,6 @@ applications. Is the extra complexity worth it?
 
 B<The API for this module is under development.>
 
-
 =head2 Generic Data Access & Manipulation
 
 The L<read>() method provided permits the following:
@@ -137,9 +134,9 @@ User feedback is an integral part of the evolution of this and other Bioperl mod
 Send your comments and suggestions preferably to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-    vsns-bcd-perl@lists.uni-bielefeld.de          - General discussion
-    vsns-bcd-perl-guts@lists.uni-bielefeld.de     - Technically-oriented discussion
-    http://bio.perl.org/MailList.html             - About the mailing lists
+   bioperl-l@bioperl.org             - General discussion
+   bioperl-guts-l@bioperl.org        - Automated bug and CVS messages
+   http://bioperl.org/MailList.shtml - About the mailing lists
 
 =head2 Reporting Bugs
 
@@ -181,7 +178,6 @@ modify it under the same terms as Perl itself.
 ##
 #'
 
-
 =head1 APPENDIX
 
 Methods beginning with a leading underscore are considered private
@@ -191,18 +187,14 @@ for documentation purposes only.
 
 =cut
 
-
-
 #####################################################################################
 ##                                 CONSTRUCTOR                                     ##
 #####################################################################################
 
-
 ## Using default constructor and destructor inherited from Bio::Root::Object.pm
 
 ## Could perhaps set the file data member.
 
-
 #####################################################################################
 ##                                 ACCESSORS                                       ##
 #####################################################################################
@@ -214,7 +206,8 @@ for documentation purposes only.
  Purpose   : Set/Get name of a file associated with an object.
  Example   : $object->file('/usr/home/me/data.txt');
  Returns   : String (full path name)
- Argument  : String (full path name) (argument only required for setting)
+ Argument  : String (full path name) OR a FileHandle or TypeGlob reference
+           : (argument only required for setting)
  Throws    : Exception if the file appears to be empty or non-existent
  Comments  : File can be text or binary.
 
@@ -228,7 +221,7 @@ sub file {
     my $self = shift; 
     if($_[0]) { 
 	my $file = $_[0];
-	if(not -s $file) {
+	if(not ref $file and not -s $file) {
 	    $self->throw("File is empty or non-existent: $file");
 	}	    
 	$self->{'_file'} = $file;
@@ -236,8 +229,6 @@ sub file {
     $self->{'_file'};
 }
 
-
-
 =head2 set_fh
 
  Usage     : $self->set_fh( named_parameters )
@@ -317,8 +308,6 @@ sub set_fh {
     }
 }
 
-
-
 =head2 _open_fh
 
  Purpose   : Creates a new FileHandle object and returns it. 
@@ -357,8 +346,6 @@ sub _open_fh {
     return $filehandle;
 }
 
-
-
 =head2 _close_fh
 
  Purpose   : Destroy a FileHandle object.
@@ -383,7 +370,6 @@ sub _close_fh {
     }
 }	       
 
-
 =head2 set_display
 
  Usage     : $self->set_display([-WHERE=>'path'],
@@ -451,8 +437,6 @@ sub set_display {
     return $self->{'_fh'};
 }
 
-
-
 =head2 set_read
 
  Purpose   : Sets a new FileHandle object for input.
@@ -498,8 +482,6 @@ sub set_read {
     return $self->{'_fh'};
 }
 
-
-
 =head2 set_display_err
 
  Purpose   : Sets a new FileHandle object for outputing error information.
@@ -538,12 +520,10 @@ sub set_display_err {
     return $self->{'_fherr'};
 }
 
-
 #####################################
 #    GET ACCESSORS
 #####################################
 
-
 =head2 show
 
  Usage     : $self->show()
@@ -560,8 +540,6 @@ See also   : L<set_display>()
 sub show { my $self= shift; $self->{'_show'}; }
 #----------
 
-
-
 =head2 fh
 
  Usage     : $object->fh(['name'])
@@ -604,17 +582,14 @@ sub fh {
     }
 }
 
-
 #####################################################################################
 ##                             INSTANCE METHODS                                    ##
 #####################################################################################
 
-
 ##
 ##  INPUT METHODS:
 ##
 
-
 =head2 read
 
  Usage     : $object->read(<named parameters>);
@@ -705,6 +680,8 @@ sub read {
     my $FH = $Util->create_filehandle( -client => $self, @param);
 
     # Set the record separator (if necessary) using dynamic scope.
+    my $prev_rec_sep;
+    $prev_rec_sep = $/  if scalar $rec_sep;  # save the previous rec_sep
     local $/ = $rec_sep if scalar $rec_sep;
 
     # Verify that we have a proper reference to a function.
@@ -716,12 +693,24 @@ sub read {
 
     $DEBUG && printf STDERR "$ID: read(): rec_sep = %s; func = %s\n",$/, ($func_ref?'defined':'none');
     
-    my($data, $lines);
+    my($data, $lines, $alarm_available);
+
+    $alarm_available = 1;
+
+    eval {
+        alarm(0);
+    };
+    if($@) {
+        # alarm() not available (ActiveState perl for win32 doesn't have it.
+        # See jitterbug PR#98)
+        $alarm_available = 0;
+    }
 
     $SIG{ALRM} = sub { die "Timed out!"; };
  
     eval {
-	 alarm($wait);
+        $alarm_available and alarm($wait);
+        
       READ_LOOP:
 	while(<$FH>) {
 	    # Default behavior: read all lines.
@@ -730,9 +719,11 @@ sub read {
 #	    next if m@^(\s*|$/*)$@; 
 	    
 	    $lines++;
-	    alarm(0);  # Deactivate the alarm as soon as we start reading.
+            $alarm_available and alarm(0);  # Deactivate the alarm as soon as we start reading.
 	    my($result);
 	    if($func_ref) {
+		# Need to reset $/ for any called function.
+		local $/ = $prev_rec_sep if defined $prev_rec_sep;
 		$result = &$func_ref($_) or last READ_LOOP;
 	    } else {
 		$data .= $_;
@@ -743,8 +734,8 @@ sub read {
 	 $self->throw("Timed out while waiting for input from $self->{'_input_type'}.", "Timeout period = $wait seconds.\nFor a longer time out period, supply a -wait => <seconds> parameter\n".
 		     "or edit \$TIMEOUT_SECS in Bio::Root::Global.pm.");
     } elsif($@ =~ /\S/) {
-         my $err = $@;
-	 $self->throw("Unexpected error during read: $err");
+        my $err = $@;
+        $self->throw("Unexpected error during read: $err");
     }
 
     close ($FH) unless $self->{'_input_type'} eq 'STDIN';
@@ -762,12 +753,10 @@ sub read {
     undef;
 }
 
-
 ##
 ##  OUTPUT METHODS:
 ##
 
-
 =head2 display
 
  Usage     : $self->set_display(named parameters)
@@ -805,8 +794,6 @@ sub display {
     1;
 }
 
-
-
 =head2 _print_stats_header
 
  Usage     : n/a; internal method.
@@ -827,15 +814,10 @@ sub _print_stats_header {
     printf $OUT "%s\n", '-'x60;
 }
 
-
-
-
 ##
 ##  FILE MANIPULATION METHODS:
 ##
 
-
-
 =head2 file_date
 
  Usage     : $object->file_date( %named_parameters);
@@ -870,8 +852,6 @@ sub file_date {
     $Util->file_date($file, $fmt);  
 }
 
-
-
 =head2 compress_file
 
  Usage     : $object->compress_file([filename]);
@@ -938,8 +918,6 @@ sub compress_file {
     $newfile;
 }
 
-
-
 =head2 uncompress_file
 
  Usage     : $object->uncompress_file([filename]);
@@ -993,7 +971,6 @@ sub uncompress_file {
     $newfile;
 }
 
-
 =head2 delete_file
 
  Usage     : $object->delete_file([filename]);
@@ -1043,8 +1020,6 @@ sub delete_file {
     $file;
 }
 
-
-
 1;
 __END__
 
@@ -1095,7 +1070,6 @@ all or some of the following fields:
  
 =cut
 
-
 MODIFICATION NOTES:
 -------------------
 
@@ -1130,4 +1104,3 @@ MODIFICATION NOTES:
 0.031, 2 Sep 1998, sac:
    * Doc changes only
 
-
