@@ -1,4 +1,3 @@
-
 #
 # BioPerl module for Bio::Seq
 #
@@ -64,9 +63,9 @@ and other Bioperl modules. Send your comments and suggestions preferably
  to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-  vsns-bcd-perl@lists.uni-bielefeld.de          - General discussion
-  vsns-bcd-perl-guts@lists.uni-bielefeld.de     - Technically-oriented discussion
-  http://bio.perl.org/MailList.html             - About the mailing lists
+   bioperl-l@bioperl.org             - General discussion
+   bioperl-guts-l@bioperl.org        - Automated bug and CVS messages
+   http://bioperl.org/MailList.shtml - About the mailing lists
 
 =head2 Reporting Bugs
 
@@ -89,12 +88,10 @@ The rest of the documentation details each of the object methods. Internal metho
 
 =cut
 
-
 # Let the code begin...
 
-
 package Bio::Seq;
-use vars qw(@ISA);
+use vars qw(@ISA $VERSION);
 use strict;
 use Bio::SeqI;
 
@@ -104,6 +101,8 @@ use Bio::Root::Object;
 use Bio::Annotation;
 use Bio::PrimarySeq;
 
+$VERSION = '0.6.2';
+
 @ISA = qw(Bio::Root::Object Bio::SeqI);
 # new() is inherited from Bio::Root::Object
 
@@ -114,7 +113,6 @@ sub _initialize {
   my($ann);
   my $make = $self->SUPER::_initialize(@args);
 
-
   # this is way too sneaky probably. We delegate the construction of
   # the Seq object onto PrimarySeq and then pop primary_seq into
   # our primary_seq slot
@@ -156,7 +154,6 @@ of course, you are free to use these functions anyway.
            case (some users... want mixed case!)
  Returns : A scalar
 
-
 =cut
 
 sub seq {
@@ -167,6 +164,22 @@ sub seq {
    return $self->primary_seq->seq();
 }
 
+=head2 length
+
+ Title   : length
+ Usage   : $len = $seq->length()
+ Function:
+ Example :
+ Returns : integer representing the length of the sequence.
+ Args    :
+
+=cut
+
+sub length {
+   my ($self) = @_;
+   return $self->primary_seq->length();
+}
+
 =head2 subseq
 
  Title   : subseq
@@ -180,12 +193,11 @@ sub seq {
  Returns : a string
  Args    :
 
-
 =cut
 
 sub subseq {
    my ($self,$s,$e) = @_;
-   return $self->primary_seq->subseq($s,$e);
+   return $self->{'primary_seq'}->subseq($s,$e);
 }
 
 =head2 display_id
@@ -210,7 +222,6 @@ sub subseq {
  Returns : A string
  Args    : None
 
-
 =cut
 
 sub display_id {
@@ -221,8 +232,6 @@ sub display_id {
    return $self->primary_seq->display_id();
 }
 
-
-
 =head2 accession_number
 
  Title   : accession_number
@@ -239,7 +248,6 @@ sub display_id {
  Returns : A string
  Args    : None
 
-
 =cut
 
 sub accession_number {
@@ -250,7 +258,6 @@ sub accession_number {
    return $self->primary_seq->accession_number();
 }
 
-
 =head2 desc
 
  Title   : desc
@@ -260,7 +267,6 @@ sub accession_number {
  Returns : 
  Args    :
 
-
 =cut
 
 sub desc {
@@ -272,9 +278,6 @@ sub desc {
    return $self->primary_seq->desc();
 }
 
-
-
-
 =head2 primary_id
 
  Title   : primary_id
@@ -292,7 +295,6 @@ sub desc {
  Returns : A string
  Args    : None
 
-
 =cut
 
 sub primary_id {
@@ -330,7 +332,6 @@ sub primary_id {
  Returns : 1 or 0
  Args    :
 
-
 =cut
 
 sub can_call_new {
@@ -354,7 +355,6 @@ sub can_call_new {
            has to guess.
  Args    : none
 
-
 =cut
 
 sub moltype {
@@ -397,7 +397,6 @@ dealing with this is welcome to give it a go.
  Returns : A new (fresh) Bio::Seq object
  Args    : none
 
-
 =cut
 
 =head2 trunc
@@ -410,7 +409,6 @@ dealing with this is welcome to give it a go.
  Returns : a fresh Bio::Seq object
  Args    :
 
-
 =cut
 
 =head2 id
@@ -422,7 +420,6 @@ dealing with this is welcome to give it a go.
  Returns : 
  Args    :
 
-
 =cut
 
 sub  id {
@@ -440,7 +437,6 @@ sub  id {
  Returns : 
  Args    :
 
-
 =cut
 
 =head1 Methods for Backward Compatibility
@@ -460,7 +456,6 @@ the old system.
  Returns : 
  Args    :
 
-
 =cut
 
 =head2 ary
@@ -472,7 +467,6 @@ the old system.
  Returns : 
  Args    :
 
-
 =cut
 
 =head2 getseq
@@ -484,7 +478,6 @@ the old system.
  Returns : 
  Args    :
 
-
 =cut
 
 =head2 type
@@ -496,7 +489,6 @@ the old system.
  Returns :
  Args    :
 
-
 =cut
 
 =head1 Seq only methods
@@ -513,7 +505,6 @@ found on the Bio::PrimarySeq object
  Returns : value of primary_seq
  Args    : newvalue (optional)
 
-
 =cut
 
 sub primary_seq {
@@ -550,7 +541,6 @@ sub primary_seq {
  Returns : value of annotation
  Args    : newvalue (optional)
 
-
 =cut
 
 sub annotation {
@@ -571,22 +561,20 @@ sub annotation {
  Returns : 
  Args    :
 
-
 =cut
 
 sub add_SeqFeature {
    my ($self,@feat) = @_;
    my ($fseq,$aseq);
 
-
    foreach my $feat ( @feat ) {
        if( !$feat->isa("Bio::SeqFeatureI") ) {
 	   $self->throw("$feat is not a SeqFeatureI and that's what we expect...");
        }
        
-       if( $feat->can("seq") ) {
-	   $fseq = $feat->seq;
-	   $aseq = $self->seq;
+       if( $feat->can("entire_seq") ) {
+	   $fseq = $feat->entire_seq;
+	   $aseq = $self->primary_seq;
 	   
 	   if( defined $aseq ) {
 	       if( defined $fseq ) {
@@ -600,12 +588,35 @@ sub add_SeqFeature {
 		   }
 	       }
 	   } # end of if aseq
-       } # end of if the feat can seq
+       } # end of if the feat can entire_seq
        
        push(@{$self->{'_as_feat'}},$feat);
    }
 }
 
+=head2 feature_count
+
+ Title   : feature_count
+ Usage   : $seq-feature_count()
+ Function: Return the number of SeqFeatures attached to a sequence
+ Example :
+ Returns : number of SeqFeatures
+ Args    : none
+
+=cut
+
+sub feature_count {
+    my ($self) = @_;
+    
+    if (defined($self-{'_as_feat'})) {
+	return ($#{$self-{'_as_feat'}} + 1);
+    } else {
+	return 0;
+    }
+}
+
+
+
 =head2 top_SeqFeatures
 
  Title   : top_SeqFeatures
@@ -615,7 +626,6 @@ sub add_SeqFeature {
  Returns : 
  Args    :
 
-
 =cut
 
 sub top_SeqFeatures {
@@ -634,7 +644,6 @@ sub top_SeqFeatures {
  Returns : 
  Args    :
 
-
 =cut
 
 sub all_SeqFeatures {
@@ -648,7 +657,6 @@ sub all_SeqFeatures {
    return @array;
 }
 
-
 sub _retrieve_subSeqFeature {
     my ($arrayref,$feat) = @_;
 
@@ -668,7 +676,6 @@ sub _retrieve_subSeqFeature {
  Returns : 
  Args    :
 
-
 =cut
 
 sub fetch_SeqFeatures {
@@ -677,7 +684,6 @@ sub fetch_SeqFeatures {
    $self->throw("Not implemented yet");
 }
 
-
 =head2 species
 
  Title   : species
@@ -687,7 +693,6 @@ sub fetch_SeqFeatures {
  Returns : Bio::Species object
  Args    : Bio::Species object or none;
 
-
 =cut
 
 sub species {
@@ -721,7 +726,6 @@ all the information that is required.
  Returns : value of division
  Args    : newvalue (optional)
 
-
 =cut
 
 sub division {
@@ -742,7 +746,6 @@ sub division {
  Returns : type of molecule (DNA, mRNA)
  Args    : newvalue (optional)
 
-
 =cut
 
 sub molecule {
@@ -758,13 +761,12 @@ sub molecule {
 =head2 add_date
 
  Title   : add_date
- Usage   : $self->add_domment($ref)
+ Usage   : $self->add_date($ref)
  Function: adds a date
  Example :
  Returns : 
  Args    :
 
-
 =cut
 
 sub add_date {
@@ -783,7 +785,6 @@ sub add_date {
  Returns : 
  Args    :
 
-
 =cut
 
 sub each_date {
@@ -802,16 +803,12 @@ sub each_date {
  Returns : value of accession
  Args    : newvalue (optional)
 
-
 =cut
 
 sub accession {
    my ($obj,$value) = @_;
-   if( defined $value) {
-      $obj->{'accession'} = $value;
-    }
-    return $obj->{'accession'};
-
+   
+   return $obj->accession_number($value);
 }
 
 =head2 add_secondary_accession
@@ -823,7 +820,6 @@ sub accession {
  Returns : 
  Args    :
 
-
 =cut
 
 sub add_secondary_accession {
@@ -842,7 +838,6 @@ sub add_secondary_accession {
  Returns : 
  Args    :
 
-
 =cut
 
 sub each_secondary_accession {
@@ -858,7 +853,6 @@ sub each_secondary_accession {
  Returns : value of sv
  Args    : newvalue (optional)
 
-
 =cut
 
 sub sv {
@@ -879,7 +873,6 @@ sub sv {
  Returns : value of keywords
  Args    : newvalue (optional)
 
-
 =cut
 
 sub keywords {
@@ -892,11 +885,3 @@ sub keywords {
 
 }
 
-
-
-
-
-
-
-
-
