@@ -1,4 +1,3 @@
-
 #
 # BioPerl module for Bio::SeqIO
 #
@@ -98,7 +97,6 @@ This makes the simplest ever reformatter
 
     print $out $_ while <$in>;
 
-
 =head1 CONSTRUCTORS
 
 =head2 Bio::SeqIO->new()
@@ -202,9 +200,9 @@ and other Bioperl modules. Send your comments and suggestions preferably
  to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-  vsns-bcd-perl@lists.uni-bielefeld.de          - General discussion
-  vsns-bcd-perl-guts@lists.uni-bielefeld.de     - Technically-oriented discussion
-  http://bio.perl.org/MailList.html             - About the mailing lists
+   bioperl-l@bioperl.org             - General discussion
+   bioperl-guts-l@bioperl.org        - Automated bug and CVS messages
+   http://bioperl.org/MailList.shtml - About the mailing lists
 
 =head2 Reporting Bugs
 
@@ -310,7 +308,6 @@ sub newFh {
 
 =cut
 
-
 sub fh {
   my $self = shift;
   my $class = ref($self) || $self;
@@ -407,7 +404,6 @@ sub next_seq {
  Returns : A Bio::PrimarySeqI object
  Args    : none
 
-
 =cut
 
 sub next_primary_seq{
@@ -436,7 +432,6 @@ sub write_seq {
     $self->throw("Sorry, you cannot write to a generic Bio::SeqIO object.");
 }
 
-
 =head2 moltype
 
  Title   : moltype
@@ -470,7 +465,6 @@ sub moltype {
  Returns : 
  Args    :
 
-
 =cut
 
 sub close{
@@ -512,6 +506,28 @@ sub _readline {
   return $line;
 }
 
+=head2 _concatenate_lines
+
+ Title   : _concatenate_lines
+ Usage   : $s = _concatenate_lines($line, $continuation_line)
+ Function: Private. Concatenates two strings assuming that the second stems
+           from a continuation line of the first. Adds a space between both
+           unless the first ends with a dash.
+
+           Takes care of either arg being empty.
+ Example :
+ Returns : A string.
+ Args    :
+
+=cut
+
+sub _concatenate_lines {
+    my ($self, $s1, $s2) = @_;
+
+    $s1 .= " " if($s1 && ($s1 !~ /-$/) && $s2);
+    return ($s1 ? $s1 : "") . ($s2 ? $s2 : "");
+}
+
 =head2 _filehandle
 
  Title   : _filehandle
@@ -521,7 +537,6 @@ sub _readline {
  Returns : value of _filehandle
  Args    : newvalue (optional)
 
-
 =cut
 
 sub _filehandle {
