@@ -34,9 +34,9 @@ and other Bioperl modules. Send your comments and suggestions preferably
  to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-  vsns-bcd-perl@lists.uni-bielefeld.de          - General discussion
-  vsns-bcd-perl-guts@lists.uni-bielefeld.de     - Technically-oriented discussion
-  http://bio.perl.org/MailList.html             - About the mailing lists
+   bioperl-l@bioperl.org             - General discussion
+   bioperl-guts-l@bioperl.org        - Automated bug and CVS messages
+   http://bioperl.org/MailList.shtml - About the mailing lists
 
 =head2 Reporting Bugs
 
@@ -59,10 +59,8 @@ The rest of the documentation details each of the object methods. Internal metho
 
 =cut
 
-
 # Let the code begin...
 
-
 package Bio::SeqIO::FTHelper;
 use vars qw(@ISA);
 use strict;
@@ -71,7 +69,6 @@ use strict;
 
 use Bio::Root::Object;
 
-
 @ISA = qw(Bio::Root::Object);
 # new() is inherited from Bio::Root::Object
 
@@ -98,7 +95,6 @@ sub _initialize {
  Returns : an array of FThelpers
  Args    : seq features
 
-
 =cut
 
 =head2 _generic_seqfeature
@@ -109,7 +105,6 @@ sub _initialize {
  Returns : TRUE on success and otherwise FALSE
  Args    : Bio::Seq, string indicating the source (GenBank/EMBL/SwissProt)
 
-
 =cut
 
 sub _generic_seqfeature {
@@ -215,7 +210,6 @@ sub _generic_seqfeature {
  Returns : TRUE on success and otherwise FALSE
  Args    : Bio::SeqFeatureI, string
 
-
 =cut
 
 sub _parse_loc {
@@ -472,7 +466,6 @@ sub from_SeqFeature {
  Returns : value of key
  Args    : newvalue (optional)
 
-
 =cut
 
 sub key {
@@ -493,7 +486,6 @@ sub key {
  Returns : value of loc
  Args    : newvalue (optional)
 
-
 =cut
 
 sub loc {
@@ -505,7 +497,6 @@ sub loc {
 
 }
 
-
 =head2 field
 
  Title   : field
@@ -515,7 +506,6 @@ sub loc {
  Returns :
  Args    :
 
-
 =cut
 
 sub field {
@@ -533,7 +523,6 @@ sub field {
  Returns :
  Args    :
 
-
 =cut
 
 sub add_field {
@@ -546,4 +535,3 @@ sub add_field {
 
 }
 
-
