@@ -1,4 +1,3 @@
-
 #
 # BioPerl module for SimpleAlign
 #
@@ -81,9 +80,9 @@ User feedback is an integral part of the evolution of this and other Bioperl mod
 Send your comments and suggestions preferably to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-    vsns-bcd-perl@lists.uni-bielefeld.de          - General discussion
-    vsns-bcd-perl-guts@lists.uni-bielefeld.de     - Technically-oriented discussion
-    http://bio.perl.org/MailList.html             - About the mailing lists
+   bioperl-l@bioperl.org             - General discussion
+   bioperl-guts-l@bioperl.org        - Automated bug and CVS messages
+   http://bioperl.org/MailList.shtml - About the mailing lists
 
 =head2 Reporting Bugs
 
@@ -111,10 +110,8 @@ The rest of the documentation details each of the object methods. Internal metho
 
 =cut
 
-
 # Let the code begin...
 
-
 package Bio::SimpleAlign;
 use vars qw(@ISA);
 use strict;
@@ -124,7 +121,6 @@ use strict;
 use Bio::Root::Object;
 use Bio::LocatableSeq;         # uses Seq's as list 
 
-
 @ISA = qw(Bio::Root::Object);
 # new() is inherited from Bio::Root::Object
 
@@ -149,9 +145,6 @@ sub _initialize {
   return $make; # success - we hope!
 }
 
-
-
-
 =head2 addSeq
 
  Title     : addSeq
@@ -167,7 +160,6 @@ sub _initialize {
 
 =cut
 
-
 sub addSeq {
     my $self = shift;
     my $seq  = shift;
@@ -182,7 +174,6 @@ sub addSeq {
     $start = $seq->start();
     $end  = $seq->end(); 
 
-
     if( !defined $order ) {
 	$order = keys %{$self->{'seq'}};
     }
@@ -204,12 +195,8 @@ sub addSeq {
 
     $self->{'seq'}->{$name} = $seq;
 
-
 }
 
-
-
-
 =head2 column_from_residue_number
 
  Title   : column_from_residue_number
@@ -264,9 +251,6 @@ sub column_from_residue_number {
 
 }
 
-
-
-
 =head2 consensus_string
 
  Title     : consensus_string
@@ -304,7 +288,6 @@ sub consensus_aa {
     my $point = shift;
     my ($seq,%hash,$count,$letter,$key);
 
-
     foreach $seq ( $self->eachSeq() ) {
 	$letter = substr($seq->seq,$point,1);
 	($letter =~ /\./) && next;
@@ -325,9 +308,6 @@ sub consensus_aa {
     return $letter;
 }
 
-
-
-
 =head2 each_alphabetically
 
  Title     : each_alphabetically
@@ -353,7 +333,6 @@ sub each_alphabetically {
 	$hash{$nse} = $seq;
     }
 
-
     foreach $nse ( sort alpha_startend keys %hash) {
 	push(@arr,$hash{$nse});
     }
@@ -376,9 +355,6 @@ sub alpha_startend {
 
 }
 
-
-
-
     
 =head2 eachSeq
 
@@ -401,7 +377,6 @@ sub eachSeq {
 
     foreach $order ( sort { $a <=> $b } keys %{$self->{'order'}} ) {
 	if( exists $self->{'seq'}->{$self->{'order'}->{$order}} ) {
-	    #print STDOUT sprintf("Putting %s\n", $self->{'order'}->{$order});
 	    push(@arr,$self->{'seq'}->{$self->{'order'}->{$order}});
 	}
     }
@@ -409,9 +384,6 @@ sub eachSeq {
     return @arr;
 }
 
-
-
-
     
 =head2 eachSeqWithId
 
@@ -439,12 +411,9 @@ sub eachSeqWithId {
     }
     return @arr; 
 
-
     return @arr;
 }
 
-
-
 sub get_displayname {
     my $self = shift;
     my $name = shift;
@@ -456,8 +425,6 @@ sub get_displayname {
     }
 }
 
-
-
 =head2 id
 
  Title     : id
@@ -479,7 +446,6 @@ sub id {
     return $self->{'id'};
 }
 
-
 =head2 is_flush
 
  Title     : is_flush
@@ -517,7 +483,6 @@ sub is_flush {
     return 1;
 }
 
-
 =head2 length_aln
 
  Title     : length_aln()
@@ -549,8 +514,6 @@ sub length_aln {
     return $length;
 }
 
-
-
 =head2 map_chars
 
  Title     : map_chars
@@ -570,7 +533,6 @@ sub length_aln {
 
 =cut
 
-
 sub map_chars {
     my $self = shift;
     my $from = shift;
@@ -584,9 +546,6 @@ sub map_chars {
     }
 }
 
-
-
-
 sub maxdisplayname_length {
     my $self = shift;
     my $maxname = (-1);
@@ -603,8 +562,6 @@ sub maxdisplayname_length {
     return $maxname;
 }
 
-
-
 sub maxname_length {
     my $self = shift;
     my $maxname = (-1);
@@ -621,9 +578,6 @@ sub maxname_length {
     return $maxname;
 }
 
-
-
-
 sub maxnse_length {
     my $self = shift;
     my $maxname = (-1);
@@ -640,8 +594,6 @@ sub maxnse_length {
     return $maxname;
 }
 
-
-
 =head2 no_residues
 
  Title     : no_residues
@@ -657,7 +609,6 @@ sub maxnse_length {
 
 =cut
 
-
 sub no_residues {
     my $self = shift;
     my $count = 0;
@@ -671,8 +622,6 @@ sub no_residues {
     return $count;
 }
 
-
-
 =head2 no_sequences
 
  Title     : no_sequences
@@ -694,8 +643,6 @@ sub no_sequences {
     return scalar($self->eachSeq);
 }
 
-
-
 =head2 percentage_identity
 
  Title   : percentage_identity
@@ -729,7 +676,6 @@ sub percentage_identity{
        }
    }
 
-
    foreach my $seq (@seqs)  {
        my @seqChars = $seq->ary();
        for( my $column=0; $column < @seqChars; $column++ ) {
@@ -754,8 +700,6 @@ sub percentage_identity{
    return ($total / $divisor )*100.0;
 }
 
-
-
 =head2 purge
 
  Title   : purge
@@ -836,9 +780,6 @@ sub purge{
   return @ret;
 }
 
-
-
-
 =head2 read_fasta
 
  Title     : read_fasta
@@ -873,7 +814,7 @@ sub read_fasta {
 		} else {
 		    $seqname=$name;
 		    $start = 1;
-		    $end = length($align{$name});
+		    $end = length($seqchar);
 		}
 		
 		$seq = new Bio::LocatableSeq('-seq'=>$seqchar,
@@ -903,7 +844,7 @@ sub read_fasta {
     } else {
 	$seqname=$name;
 	$start = 1;
-	$end = length($align{$name});
+	$end = length($seqchar);
     }
     
     $seq = new Bio::LocatableSeq('-seq'=>$seqchar,
@@ -920,8 +861,6 @@ sub read_fasta {
 }
 	    
 
-
-
 =head2 read_mase
 
  Title     : read_mase
@@ -978,7 +917,6 @@ sub read_mase {
 			    '-end'=>$end, 
 			    );
 
-
 	
 	$self->addSeq($add);
 
@@ -988,9 +926,6 @@ sub read_mase {
     return $count;
 }
 
-
-
-
 =head2 read_MSF
 
  Title   : read_MSF
@@ -1003,7 +938,6 @@ sub read_mase {
  Returns : 
  Args    : filehandle
 
-
 =cut
 
 sub read_MSF{
@@ -1024,7 +958,7 @@ sub read_MSF{
    # alignment section
 
    while( <$fh> ) {
-       /^\s+(\S+)\s+(.*)$/ && do {
+       /^\s*(\S+)\s+(.*)$/ && do {
 	   $name = $1;
 	   $str = $2;
 	   if( ! exists $hash{$name} ) {
@@ -1066,9 +1000,6 @@ sub read_MSF{
    return $count;
 }
 
-
-
-
 =head2 read_Pfam
 
  Title     : read_Pfam
@@ -1109,7 +1040,6 @@ sub read_Pfam {
 	$end = $3;
 	$seq = $4;
 
-
 	$add = new Bio::LocatableSeq('-seq'=>$seq,
 			    '-id'=>$name,
 			    '-start'=>$start,
@@ -1124,7 +1054,6 @@ sub read_Pfam {
     return $count;
 }
 
-
 	
 
 =head2 read_Pfam_file
@@ -1159,8 +1088,6 @@ sub read_Pfam_file {
     return $out;
 }
 
-
-
 =head2 read_Prodom
 
  Title   : read_Prodom
@@ -1205,8 +1132,6 @@ sub read_Prodom{
    }
 }
 
-
-
 =head2 read_selex
 
  Title     : read_selex
@@ -1284,8 +1209,6 @@ sub read_selex {
     return $count; 
 }
 
-
-
 =head2 read_stockholm
 
  Title     : read_stockholm
@@ -1325,10 +1248,6 @@ sub read_stockholm {
     return $self->read_selex($in);
 }
 
-
-
-
-
 =head2 removeSeq
 
  Title     : removeSeq
@@ -1380,9 +1299,6 @@ sub removeSeq {
     # because eachSeq will handle it
 }
 
-
-
-
 sub set_displayname {
     my $self = shift;
     my $name = shift;
@@ -1392,8 +1308,6 @@ sub set_displayname {
     $self->{dis_name}->{$name} = $disname;
 }
 
-
-
 =head2 set_displayname_count
 
  Title     : set_displayname_count
@@ -1409,7 +1323,6 @@ sub set_displayname {
 
 =cut
 
-
 sub set_displayname_count {
     my $self= shift;
     my (@arr,$name,$seq,$count,$temp,$nse);
@@ -1435,9 +1348,6 @@ sub set_displayname_count {
 
 }
 
-
-
-
 =head2 set_displayname_flat
 
  Title     : set_displayname_flat
@@ -1463,8 +1373,6 @@ sub set_displayname_flat {
     }
 }
 
-
-
 =head2 set_displayname_normal
 
  Title     : set_displayname_normal
@@ -1490,8 +1398,6 @@ sub set_displayname_normal {
     }
 }
 
-
-
    
 =head2 sort_alphabetically
 
@@ -1512,7 +1418,6 @@ sub sort_alphabetically {
     my $self = shift;
     my ($seq,$nse,@arr,%hash,$count);
 
-
     foreach $seq ( $self->eachSeq() ) {
 	$nse = $seq->get_nse("-","-");
 	$hash{$nse} = $seq;
@@ -1530,9 +1435,6 @@ sub sort_alphabetically {
 
 }
 
-
-
-
 =head2 uppercase
 
  Title     : uppercase()
@@ -1561,9 +1463,6 @@ sub uppercase {
     }
 }
 
-
-
-
 =head2 write_clustalw
 
  Title     : write_clustalw
@@ -1601,7 +1500,6 @@ sub write_clustalw {
     
 }
 
-
 =head2 write_fasta
 
  Title     : write_fasta
@@ -1636,7 +1534,6 @@ sub write_fasta {
     }
 }
 
-
 =head2 write_MSF
 
  Title     : write_MSF
@@ -1688,7 +1585,7 @@ sub write_MSF {
     #
     # ok - heavy handed, but there you go.
     #
-    print "\n//\n";
+    print $file "\n//\n";
 
     while( $count < $length ) {
 	
@@ -1724,14 +1621,12 @@ sub write_MSF {
 	    print $file "\n";
 	} # end of each sequence
 
-	print "\n\n";
+	print $file "\n\n";
 
 	$count = $tempcount;
     }				
 }
 
-
-
 =head2 write_Pfam
 
  Title     : write_Pfam
@@ -1763,8 +1658,6 @@ sub write_Pfam {
     }
 }
 
-
-
 =head2 write_selex
 
  Title     : write_selex
@@ -1795,8 +1688,5 @@ sub write_selex {
     }
 }
 
-
-
-
 1;
 
