@@ -3,7 +3,7 @@
 # AUTHOR  : Steve A. Chervitz (sac@genome.stanford.edu)
 # CREATED : March 1996
 # STATUS  : Alpha
-# REVISION: $Id: HSP.pm,v 1.6 2000/03/22 09:41:11 sac Exp $
+# REVISION: $Id: HSP.pm,v 1.6.2.3 2000/09/21 16:35:01 sac Exp $
 #
 # For the latest version and documentation, visit the distribution site:
 #    http://genome-www.stanford.edu/perlOOP/bioperl/blast/
@@ -28,7 +28,7 @@ use strict;
 use vars qw($ID $VERSION $GAP_SYMBOL @SCORE_CUTOFFS $Revision %STRAND_SYMBOL);
 $ID       = 'Bio::Tools::Blast::HSP';
 $VERSION  = 0.09;
-$Revision = '$Id: HSP.pm,v 1.6 2000/03/22 09:41:11 sac Exp $';  #'
+$Revision = '$Id: HSP.pm,v 1.6.2.3 2000/09/21 16:35:01 sac Exp $';  #'
 
 $GAP_SYMBOL    = '-';          # Need a more general way to handle gap symbols.
 @SCORE_CUTOFFS = ( 100, 30 );  # Bit score cutoffs (see homol_score()).
@@ -100,7 +100,6 @@ and relies on B<Bio::Tools::Sbjct.pm> as a container for HSP.pm objects.
 B<Bio::Seq.pm> and B<Bio::UnivAln.pm> are employed for creating sequence
 and alignment objects, respectively.
 
-
 =head2 Relationship to UnivAln.pm & Seq.pm
 
 HSP.pm can provide the query or sbjct sequence as a B<Bio::Seq.pm> object
@@ -110,7 +109,6 @@ via the L<get_aln>() method. Creation of alignment objects is not automatic when
 constructing the HSP.pm object since this level of functionality is not always
 required and would generate a lot of extra overhead when crunching many reports.
 
-
 =head1 FEEDBACK
 
 =head2 Mailing Lists 
@@ -119,9 +117,9 @@ User feedback is an integral part of the evolution of this and other Bioperl mod
 Send your comments and suggestions preferably to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-    vsns-bcd-perl@lists.uni-bielefeld.de          - General discussion
-    vsns-bcd-perl-guts@lists.uni-bielefeld.de     - Technically-oriented discussion
-    http://bio.perl.org/MailList.html             - About the mailing lists
+   bioperl-l@bioperl.org             - General discussion
+   bioperl-guts-l@bioperl.org        - Automated bug and CVS messages
+   http://bioperl.org/MailList.shtml - About the mailing lists
 
 =head2 Reporting Bugs
 
@@ -163,8 +161,6 @@ modify it under the same terms as Perl itself.
 
 =cut
 
-
-
 #
 ##
 ###
@@ -225,7 +221,6 @@ sub _initialize {
 ##                                  ACCESSORS                                      ##
 #####################################################################################
 
-
 =head2 _set_data
 
  Usage     : n/a; called automatically during object construction.
@@ -309,8 +304,6 @@ sub _set_data {
       }
 }
 
-
-
 =head2 _set_score_stats
 
  Usage     : n/a; called automatically by _set_data()
@@ -373,8 +366,6 @@ sub _set_score_stats {
 
 }
 
-
-
 =head2 _set_match_stats
 
  Usage     : n/a; called automatically by _set_data()
@@ -432,8 +423,6 @@ sub _set_match_stats {
 #    }
 }
 
-
-
 =head2 _set_seq_data
 
  Usage     : n/a; called automatically when sequence data is requested.
@@ -464,8 +453,6 @@ sub _set_seq_data {
     $self->{'_set_seq_data'} = 1;
 }
 
-
-
 =head2 _set_seq
 
  Usage     : n/a; called automatically by _set_seq_data()
@@ -549,7 +536,6 @@ sub _set_seq {
 #    }
 }
 
-
 =head2 _set_residues
 
  Usage     : n/a; called automatically when residue data is requested.
@@ -621,9 +607,6 @@ sub _set_residues {
 
 }
 
-
-
-
 =head2 _set_match_seq
 
  Usage     : n/a. Internal method.
@@ -677,8 +660,6 @@ sub _set_match_seq {
     $self->{'_matchSeq'};
 }
 
-
-
 =head2 score
 
  Usage     : $hsp_obj->score()
@@ -695,8 +676,6 @@ See Also   : L<bits>()
 sub score { my $self = shift; $self->{'_score'}; }
 #---------
 
-
-
 =head2 bits
 
  Usage     : $hsp_obj->bits()
@@ -705,7 +684,6 @@ sub score { my $self = shift; $self->{'_score'}; }
  Argument  : n/a
  Throws    : n/a
 
-
 See Also   : L<score>()
 
 =cut
@@ -714,8 +692,6 @@ See Also   : L<score>()
 sub bits { my $self = shift; $self->{'_bits'}; }
 #--------
 
-
-
 =head2 n
 
  Usage     : $hsp_obj->n()
@@ -738,8 +714,6 @@ See Also   : L<score>()
 sub n { my $self = shift; $self->{'_n'} || ''; }
 #-----
 
-
-
 =head2 frame
 
  Usage     : $hsp_obj->frame()
@@ -754,8 +728,6 @@ sub n { my $self = shift; $self->{'_n'} || ''; }
 sub frame { my $self = shift; $self->{'_frame'} || ''; }
 #---------
 
-
-
 =head2 signif()
 
  Usage     : $hsp_obj->signif()
@@ -781,8 +753,6 @@ sub signif {
     $val; 
 }
 
-
-
 =head2 expect
 
  Usage     : $hsp_obj->expect()
@@ -802,8 +772,6 @@ See Also   : L<p>()
 sub expect { my $self = shift; $self->{'_expect'}; }
 #----------
 
-
-
 =head2 p
 
  Usage     : $hsp_obj->p()
@@ -824,7 +792,6 @@ See Also   : L<expect>()
 sub p { my $self = shift; $self->{'_p'}; }
 #-----
 
-
 =head2 length
 
  Usage     : $hsp->length( [seq_type] )
@@ -856,8 +823,6 @@ sub length {
     $self->{$type.'Length'};
 }
 
-
-
 =head2 gaps
 
  Usage     : $hsp->gaps( [seq_type] )
@@ -900,8 +865,6 @@ sub gaps {
     }
 }
 
-
-
 =head2 matches
 
  Usage     : $hsp->matches([seq_type], [start], [stop]);
@@ -1000,8 +963,6 @@ sub matches {
     @data;
 }
 
-
-
 =head2 frac_identical
 
  Usage     : $hsp_object->frac_identical( [seq_type] );
@@ -1048,7 +1009,6 @@ sub frac_identical {
     sprintf( "%.2f", $self->{'_numIdentical'}/$self->{$seqType.'Length'});
 }
 
-
 =head2 frac_conserved
 
  Usage     : $hsp_object->frac_conserved( [seq_type] );
@@ -1098,7 +1058,6 @@ sub frac_conserved {
     sprintf( "%.2f", $self->{'_numConserved'}/$self->{$seqType.'Length'});
 }
 
-
 =head2 num_identical
 
  Usage     : $hsp_object->num_identical();
@@ -1120,7 +1079,6 @@ sub num_identical {
     $self->{'_numIdentical'};
 }
 
-
 =head2 num_conserved
 
  Usage     : $hsp_object->num_conserved();
@@ -1142,8 +1100,6 @@ sub num_conserved {
     $self->{'_numConserved'};
 }
 
-
-
 =head2 range
 
  Usage     : $hsp->range( [seq_type] );
@@ -1248,8 +1204,6 @@ sub end {
     }
 }
 
-
-
 =head2 strand
 
  Usage     : $hsp_object->strand( [seq_type] )
@@ -1293,12 +1247,10 @@ sub strand {
     $STRAND_SYMBOL{$self->{$seqType.'Strand'}} || 0;
 }
 
-
 #####################################################################################
 ##                            INSTANCE METHODS                                     ##
 #####################################################################################
 
-
 =head2 seq
 
  Usage     : $hsp->seq( [seq_type] );
@@ -1335,8 +1287,6 @@ sub seq {
 		  );
 }
 
-
-
 =head2 seq_str
 
  Usage     : $hsp->seq_str( seq_type );
@@ -1387,9 +1337,6 @@ sub seq_str {
     }
 }
 
-
-
-
 =head2 seq_inds
 
  Usage     : $hsp->seq_inds( seq_type, class, collapse );
@@ -1439,9 +1386,6 @@ sub seq_inds {
     return $collapse ? &collapse_nums(@ary) : @ary;
 }
 
-
-
-
 =head2 get_aln
 
  Usage     : $hsp->get_aln()
@@ -1484,7 +1428,6 @@ sub get_aln {
 		       );
 }
 
-
 =head2 display
 
  Usage     : $sbjct_object->display( %named_parameters );
@@ -1528,20 +1471,20 @@ sub display {
     } else {
 	printf( $OUT "%-15s: %.1e\n", "EXPECT", $self->{'_expect'} );
     }
+
+    my $queryLength = $self->length('query'); 
+
     printf( $OUT "%-15s: %d (%0.0f%%)\n", "IDENTICAL", $self->{'_numIdentical'}, 
-	   $self->{'_numIdentical'}/$self->{'_length'}*100 );
+	   $self->{'_numIdentical'}/$queryLength * 100 );
     printf( $OUT "%-15s: %d (%0.0f%%)  %s \n", "CONSERVED", $self->{'_numConserved'}, 
-	   $self->{'_numConserved'}/$self->{'_length'}*100,
+	   $self->{'_numConserved'}/$queryLength * 100,
 	   "includes identical" );
-    
+
     $self->_display_seq('query', $queryName, $OUT);
     $self->_display_seq('sbjct', $sbjctName, $OUT);
     $self->_display_matches($queryName, $sbjctName, $OUT);
 }
 
-
-
-
 =head2 _display_seq
 
  Usage     : n/a; called automatically by display()
@@ -1576,7 +1519,6 @@ sub _display_seq {
     }
 }
 
-
 =head2 _display_matches
 
  Usage     : n/a; called automatically by display()
@@ -1650,9 +1592,6 @@ sub _display_matches {
     }
 }
 
-
-
-
 =head2 homol_data
 
  Usage     : $data = $hsp_object->homo_data( %named_params );
@@ -1688,7 +1627,6 @@ sub homol_data {
     return ( $homolScore.' '.$self->{$seq.'Start'}.' '.$self->{$seq.'Stop'});
 }
 
-
 =head2 homol_score
 
  Usage     : $self->homol_score();
@@ -1722,7 +1660,6 @@ sub homol_score {
     else  { 3 }
 }
 
-
 #####################################################################################
 ##                                  CLASS METHODS                                  ##
 #####################################################################################
@@ -1778,7 +1715,6 @@ sub collapse_nums {
     @ca;
 }
 
-
 1;
 __END__
 
@@ -1856,7 +1792,6 @@ all or some of the following fields:
  _parent        : From Bio::Root::Object.pm. This member contains a reference to the
 		: Bio::Tools::Blast::Sbjct.pm object to which this hit belongs.
 
-
 =cut
 
 1;
