@@ -4,7 +4,7 @@
 # AUTHOR  : Steve A. Chervitz (sac@genome.stanford.edu)
 # CREATED : 28 Apr 1998
 # STATUS  : Alpha
-# REVISION: $Id: HTML.pm,v 1.3.2.2 2000/05/18 20:55:20 sac Exp $
+# REVISION: $Id: HTML.pm,v 1.3.2.3 2000/09/15 08:24:24 jgrg Exp $
 # 
 # For the latest version and documentation, visit the distribution site:
 #    http://bio.perl.org/Projects/Blast/
@@ -41,12 +41,11 @@ use vars qw( @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS
 
 $ID = 'Bio::Tools::Blast::HTML';
 $VERSION  = 0.076; 
-$Revision = '$Id: HTML.pm,v 1.3.2.2 2000/05/18 20:55:20 sac Exp $';  #'
+$Revision = '$Id: HTML.pm,v 1.3.2.3 2000/09/15 08:24:24 jgrg Exp $';  #'
 
 my $_set_markup = 0;
 my $_gi_link = '';
 
-
 ## POD Documentation:
 
 =head1 NAME
@@ -66,7 +65,6 @@ Bio::Tools::Blast::HTML.pm - Bioperl Utility module for HTML formatting Blast re
 See L<get_html_func>() for details.
 Also see B<Bio::Tools::Blast::to_html> for an example of usage.
 
-
 =head2 Removing HTML-formatting
 
     use Bio::Tools::Blast::HTML qw(&strip_html);
@@ -75,7 +73,6 @@ Also see B<Bio::Tools::Blast::to_html> for an example of usage.
 
 See L<strip_html>() for details.
 
-
 =head1 INSTALLATION
 
 This module is included with the central Bioperl distribution:
@@ -122,9 +119,9 @@ User feedback is an integral part of the evolution of this and other Bioperl mod
 Send your comments and suggestions preferably to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-    vsns-bcd-perl@lists.uni-bielefeld.de          - General discussion
-    vsns-bcd-perl-guts@lists.uni-bielefeld.de     - Technically-oriented discussion
-    http://bio.perl.org/MailList.html             - About the mailing lists
+   bioperl-l@bioperl.org             - General discussion
+   bioperl-guts-l@bioperl.org        - Automated bug and CVS messages
+   http://bioperl.org/MailList.shtml - About the mailing lists
 
 =head2 Reporting Bugs
 
@@ -148,10 +145,8 @@ Copyright (c) 1998 Steve A. Chervitz. All Rights Reserved.
 This module is free software; you can redistribute it and/or 
 modify it under the same terms as Perl itself.
 
-
 =cut
 
-
 #
 ##
 ###
@@ -160,7 +155,6 @@ modify it under the same terms as Perl itself.
 ##
 #'
 
-
 ######################  BEGIN FUNCTIONS  ########################
 
 =head1 APPENDIX
@@ -170,8 +164,6 @@ and are intended for internal use by this module. They are
 B<not> considered part of the public interface and are described here
 for documentation purposes only.
 
-
-
 =head2 get_html_func
 
  Usage     : $func_ref = &get_html_func( [array_ref] );
@@ -310,9 +302,6 @@ sub get_html_func {
     } # end sub {}
 }
 
-
-
-
 =head2 _set_markup_data
 
  Usage     : n/a; utility method used by get_html_func()
@@ -341,7 +330,6 @@ sub _set_markup_data {
     $_set_markup = 1;
 }
 
-
 =head2 _markup_database
 
  Usage     : n/a; utility method used by get_html_func()
@@ -371,7 +359,6 @@ sub _markup_database {
     $$line_ref = $_;
 }
 
-
 =head2 _markup_report
 
  Usage     : n/a; utility function used by get_html_func()
@@ -473,11 +460,9 @@ sub _markup_report {
     # SwissProt hits:
   s@^>sp\|($Word)\|($Word)?( .*)$@<a name=$1_A></a><b><a href="$DbUrl{'swpr'}$1">sp</a>:<a href="$DbUrl{'gb_p'}$1">$1|$2</a></b>$3<br>(<a href="\#$1_H">Back|<a href="\#top">Top</a>)@o;
 
-
   ## PDB ids with or without a chain identifier (GenBank format)
   s@^>pdb\|(\d\w{3})\|[\w ] (.*)$@<a name=$1_A></A><b><a href=\"$DbUrl{'3db'}$1\">pdb</A>:<a href="$DbUrl{'gb_struct'}$1">$1</a></b> (<a href="\#$1_H">Back</a>|<a href="\#top">Top</a>)  $2@o;
 
-
     ### SGD-specific markups for HSP alignment section lines:
 
   ## PDB ids without chain identifier
@@ -542,27 +527,22 @@ sub _markup_report {
 
   s@^ ?(gnl)\|($Word)?(\|$Word +)\(($Word)\)($Descrip)($Int)  ($Signif)(.*)$@$1:<a href="$DbUrl{'gb_n'}$4">$2$3</a>($4)$5$6  <A href="\#$4_A">$7</a>$8<a name="$4_H"></a>@o;
 
-
   s@^ ?(bbs|prf)\|\|?($Word)($Descrip)($Int)  ($Signif)(.*)$@$1:<a href="$DbUrl{'gb_n'}$2">$2</a> $3$4  <A href="\#$2_A">$5</a>$6<a name="$2_H"></a>@o;
 
-
   ## SwissProt accessions (GenBank format)
   s@^ ?sp\|($Word)(\|$Word)?($Descrip)($Int)  ($Signif)(.*)$@<a href="$DbUrl{'swpr'}$1">sp</a>:<a href="$DbUrl{'gb_p'}$1">$1$2</a>$3$4  <a href="\#$1_A">$5</a>$6<a name="$1_H"></a>@o;
 
   ## PDB ids with or without a chain ID (GenBank format)
   s@^ ?pdb\|($Word)\|($Word)?($Descrip)($Int)  ($Signif)(.*)$@<a href="$DbUrl{'3db'}$1">pdb</a>:<a href="$DbUrl{'gb_struct'}$1">$1_$2</a>$3$4  <a href="\#$1_A">$5</a>$6<a name="$1_H"></a>@o;
 
-
  ### SGD-specific markups for description lines:
 
   ## PDB ids without chain identifier
   s@^ ?PDB_UNIQUEP:(\d\w{3})_($Descrip)($Int)  ($Signif)(.*)$@<a href="$DbUrl{'3db'}$1">PDB</a>:<A HREF="$DbUrl{'gb_struct'}$1">$1</A>       $2$3  <a href="\#$1_A">$4</a>$5<a name="$1_H"></a>@o;
 
-
   ## PDB ids with chain identifier
   s@^ ?PDB_UNIQUEP:(\d\w{3})_(\w)($Descrip)($Int)  ($Signif)(.*)$@<a href="$DbUrl{'3db'}$1">PDB</a>:<A HREF="$DbUrl{'gb_struct'}$1">$1</A> Chain:$2$3$4  <a href="\#$1_A">$5</a>$6<a name="$1_H"></a>@o;
 
-
   s@^ ?($Word)PEPT:GI_(\d+)($Descrip)($Int)  ($Signif)(.*)$@$1:<A HREF="$DbUrl{'gb_p'}$2">GI_$2</A> $3 $4  <a href="\#$2_A">$5</a> $6<a name="$2_H"></a>@o;
 
   s@^ *WORMPEPT:(\S+)($Descrip)($Int)  ($Signif)(.*)$@WORMPEP:<A HREF="$DbUrl{'wormace'}$1">$1</a> $2 $3 <a href="\#$1_A">$4</a>$5<a name="$1_H"></a>@o;
@@ -600,9 +580,6 @@ sub _markup_report {
     $$line_ref = $_;
 }
 
-
-
-
 =head2 _prog_ref_html
 
  Usage     : n/a; utility method used by get_html_func().
@@ -646,7 +623,6 @@ QQ_REF_QQ
 
 }
 
-
 =head2 _genbank_alert
 
  Usage     : n/a; utility method used by get_html_func().
@@ -672,8 +648,6 @@ sub _genbank_alert {
 QQ_GENBANK_QQ
 }
 
-
-
 =head2 strip_html
 
  Usage     : $boolean = &strip_html( string_ref );
@@ -750,5 +724,3 @@ __END__
 #                                END OF CLASS                                       #
 #####################################################################################
 
-
-
