@@ -3,7 +3,7 @@
 # AUTHOR  : Steve A. Chervitz (sac@genome.stanford.edu) 
 # CREATED : 7 October 1996
 # STATUS  : Alpha
-# REVISION: $Id: Sbjct.pm,v 1.8.2.2 2000/05/15 17:50:21 sac Exp $
+# REVISION: $Id: Sbjct.pm,v 1.8.2.3 2000/09/15 08:24:24 jgrg Exp $
 #
 # For the latest version and documentation, visit the distribution site:
 #    http://genome-www.stanford.edu/perlOOP/bioperl/blast/
@@ -27,7 +27,7 @@ use strict;
 use vars qw($ID $VERSION %SUMMARY_OFFSET $Revision);
 $ID = 'Bio::Tools::Blast::Sbjct';
 $VERSION = 0.091;
-$Revision = '$Id: Sbjct.pm,v 1.8.2.2 2000/05/15 17:50:21 sac Exp $';  #'
+$Revision = '$Id: Sbjct.pm,v 1.8.2.3 2000/09/15 08:24:24 jgrg Exp $';  #'
 
 my $_prog       = '';
 my $_signif_fmt = '';
@@ -84,7 +84,6 @@ The terms "sbjct" and "hit" will be used interchangeably in this and related mod
 
 This module supports BLAST versions 1.x and 2.x, gapped and ungapped.
 
-
 =head2 HSP Tiling and Ambiguous Alignments
 
 If a Blast hit has more than one HSP, the Bio::Tools::Blast::Sbjct.pm object has
@@ -103,7 +102,6 @@ if this is set to 2 -- the default -- then any two sbjct or query HSP sequences
 must overlap by more than two residues to get merged into the same contig and counted
 as an overlap. See the L<BUGS> section below for "issues" with HSP tiling.
 
-
 The results of the HSP tiling is reported with the following ambiguity codes:
 
    'q' = Query sequence contains multiple sub-sequences matching
@@ -115,7 +113,6 @@ The results of the HSP tiling is reported with the following ambiguity codes:
    'qs' = Both query and sbjct sequences contain more than one
           sub-sequence with similarity to the other sequence.
 
-
 For addition information about ambiguous BLAST alignments, see
 L<_tile_hsps>() and 
 
@@ -138,13 +135,11 @@ Provides a container for Sbjct.pm objects.
 
 =back
 
-
 Bio::Tools::Blast::Sbjct.pm does not currently inherit from Bio::Root::Vector.pm
 since Bio::Root::Vector.pm may be re-designed to make it usable via delegation.
 Thus, a Blast.pm object would manage a vector of Sbjct.pm objects.
 Stay tuned.
 
-
 =head1 BUGS
 
 One consequence of the HSP tiling is that methods that rely on HSP tiling such as
@@ -159,7 +154,6 @@ For example, say we have two HSPs and the query sequence tile as follows:
                               **   **  **
  HSP2:                        -------------           (6 identical matches)
 
-
 If C<-OVERLAP> is set to some number over 4, HSP1 and HSP2 will not be tiled into a single
 contig and their numbers of identical matches will be added, giving a total of 12,
 not 10 if they had be combined into one contig. This can lead to number greater than 1.0 for
@@ -174,7 +168,6 @@ Setting C<-OVERLAP> to zero will lead to the most accurate numbers for the tilin
 methods but will be useless for detecting overlapping HSPs since all HSPs will appear to
 overlap.
 
-
 =head1 SEE ALSO
 
  Bio::Tools::Blast::HSP.pm     - Blast HSP object.
@@ -189,7 +182,6 @@ Links:
  http://bio.perl.org/Projects/Blast/        - Bioperl Blast Project     
  http://bio.perl.org/                       - Bioperl Project Homepage
 
-
 =head1 FEEDBACK
 
 =head2 Mailing Lists 
@@ -198,9 +190,9 @@ User feedback is an integral part of the evolution of this and other Bioperl mod
 Send your comments and suggestions preferably to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-    vsns-bcd-perl@lists.uni-bielefeld.de          - General discussion
-    vsns-bcd-perl-guts@lists.uni-bielefeld.de     - Technically-oriented discussion
-    http://bio.perl.org/MailList.html             - About the mailing lists
+   bioperl-l@bioperl.org             - General discussion
+   bioperl-guts-l@bioperl.org        - Automated bug and CVS messages
+   http://bioperl.org/MailList.shtml - About the mailing lists
 
 =head2 Reporting Bugs
 
@@ -228,8 +220,6 @@ modify it under the same terms as Perl itself.
 
 =cut
 
-
-
 #
 ##
 ###
@@ -238,7 +228,6 @@ modify it under the same terms as Perl itself.
 ##
 #'
 
-
 =head1 APPENDIX
 
 Methods beginning with a leading underscore are considered private
@@ -321,7 +310,6 @@ sub destroy {
 ##                                  ACCESSORS                                      ##
 #####################################################################################
 
-
 =head2 rank
 
  Usage     : $sbjct->rank( integer or string );
@@ -348,8 +336,6 @@ sub rank {
     $self->{'_rank'};
 }
 
-
-
 =head2 _set_id
 
  Usage     : n/a; automatically called by _initialize()
@@ -430,7 +416,6 @@ sub _set_id {
 #    $self->{'_db'}  = $dbID || '-';
 }
 
-
 =head2 _set_hsps
 
  Usage     : n/a; called automatically during object construction.
@@ -635,7 +620,6 @@ sub _set_desc {
 #    print "$ID: _set_desc =  $desc";<STDIN>;
 }
 
-
 =head2 _tile_hsps
 
  Usage     : n/a; called automatically during object construction or
@@ -826,8 +810,6 @@ sub _tile_hsps {
     }
 }
 
-
-
 =head2 _adjust_contigs
 
  Usage     : n/a; called automatically during object construction.
@@ -919,7 +901,6 @@ sub _adjust_contigs {
     $overlap;
 }
 
-
 =head2 ambiguous_aln
 
  Usage     : $ambig_code = $sbjct_object->ambiguous_aln();
@@ -951,8 +932,6 @@ sub ambiguous_aln {
     $self->{'_ambiguous_aln'} || '-';
 }
 
-
-
 =head2 overlap
 
  Usage     : $blast_object->overlap( [integer] );
@@ -979,9 +958,6 @@ sub overlap {
     defined $self->{'_overlap'} ? $self->{'_overlap'} : 0;
 }
 
-
-
-
 =head2 score
 
  Usage     : $sbjct_object->score();
@@ -1012,8 +988,6 @@ sub score {
     return $score;
 }
 
-
-
 =head2 bits
 
  Usage     : $sbjct_object->bits();
@@ -1045,8 +1019,6 @@ sub bits {
     return $bits;
 }
 
-
-
 =head2 n
 
  Usage     : $sbjct_object->n();
@@ -1088,8 +1060,6 @@ sub n {
     return $n;
 }
 
-
-
 =head2 frame
 
  Usage     : $sbjct_object->frame();
@@ -1120,10 +1090,6 @@ sub frame {
     return $frame;
 }
 
-
-
-
-
 =head2 p
 
  Usage     : $sbjct_object->p( [format] );
@@ -1180,8 +1146,6 @@ sub p {
     return $val;
 }
 
-
-
 =head2 expect
 
  Usage     : $sbjct_object->expect( [format] );
@@ -1229,8 +1193,6 @@ sub expect {
     return $val;
 }
 
-
-
 =head2 signif
 
  Usage     : $sbjct_object->signif( [format] );
@@ -1292,8 +1254,6 @@ sub signif {
     return $val;
 }
 
-
-
 =head2 desc
 
  Usage     : $sbjct_object->desc( [integer] );
@@ -1316,8 +1276,6 @@ sub desc {
     substr( $self->{'_desc'}, 0 ,$len ); 
 }
 
-
-
 =head2 database
 
  Usage     : $sbjct_object->database();
@@ -1338,9 +1296,6 @@ sub desc {
 sub database { my $self = shift; return $self->{'_db'}; }
 #--------------
 
-
-
-
 =head2 hsps
 
  Usage     : $sbjct_object->hsps();
@@ -1374,8 +1329,6 @@ sub hsps {
         : scalar(@{$self->{'_hsps'}});
 }
 
-
-
 =head2 hsp
 
  Usage     : $sbjct_object->hsp( [string] );
@@ -1414,8 +1367,6 @@ sub hsp {
 		 "Valid arguments: 'best', 'worst'");
 }
 
-
-
 =head2 num_hsps
 
  Usage     : $sbjct_object->num_hsps();
@@ -1441,8 +1392,6 @@ sub num_hsps {
     return scalar(@{$self->{'_hsps'}});
 }
 
-
-
 =head2 length
 
  Usage     : $sbjct_object->length();
@@ -1465,7 +1414,6 @@ sub length {
     $self->{'_length'}; 
 }    
 
-
 =head2 logical_length
 
  Usage     : $sbjct_object->logical_length( [seq_type] );
@@ -1507,8 +1455,6 @@ sub logical_length {
     return $qlen;
 }    
 
-
-
 =head2 length_aln
 
  Usage     : $sbjct_object->length_aln( [seq_type] );
@@ -1551,7 +1497,6 @@ sub length_aln {
     $data;
 }    
 
-
 =head2 gaps
 
  Usage     : $sbjct_object->gaps( [seq_type] );
@@ -1600,8 +1545,6 @@ sub gaps {
     }
 }    
 
-
-
 =head2 matches
 
  Usage     : $sbjct_object->matches( [class] );
@@ -1655,7 +1598,6 @@ sub matches {
     $self->throw("Can't get identical or conserved data: no data.");
 }
 
-
 =head2 start
 
  Usage     : $sbjct->start( [seq_type] );
@@ -1703,7 +1645,6 @@ sub start {
     }
 }
 
-
 =head2 end
 
  Usage     : $sbjct->end( [seq_type] );
@@ -1775,7 +1716,6 @@ sub range {
     return ($self->start($seqType), $self->end($seqType));
 }
 
-
 =head2 frac_identical
 
  Usage     : $sbjct_object->frac_identical( [seq_type] );
@@ -1824,8 +1764,6 @@ sub frac_identical {
     sprintf( "%.2f", $self->{'_totalIdentical'}/$self->{'_length_aln_'.$seqType});
 }
 
-
-
 =head2 frac_conserved
 
  Usage     : $sbjct_object->frac_conserved( [seq_type] );
@@ -1874,9 +1812,6 @@ sub frac_conserved {
     sprintf( "%.2f", $self->{'_totalConserved'}/$self->{'_length_aln_'.$seqType});
 }
 
-
-
-
 =head2 frac_aligned_query
 
  Usage     : $sbjct_object->frac_aligned_query();
@@ -1911,8 +1846,6 @@ sub frac_aligned_query {
     sprintf( "%.2f", $self->{'_length_aln_query'}/$self->logical_length('query'));
 }
 
-
-
 =head2 frac_aligned_hit
 
  Usage     : $sbjct_object->frac_aligned_hit();
@@ -1958,8 +1891,6 @@ sub frac_aligned_sbjct {  my $self=shift; $self->frac_aligned_hit(@_); }
 sub num_unaligned_sbjct {  my $self=shift; $self->num_unaligned_hit(@_); }
 #-----------------------  
 
-
-
 =head2 num_unaligned_hit
 
  Usage     : $sbjct_object->num_unaligned_hit();
@@ -1991,7 +1922,6 @@ sub num_unaligned_hit {
     ($num < 0 ? 0 : $num );
 }
 
-
 =head2 num_unaligned_query
 
  Usage     : $sbjct_object->num_unaligned_query();
@@ -2023,8 +1953,6 @@ sub num_unaligned_query {
     ($num < 0 ? 0 : $num );
 }
 
-
-
 =head2 seq_inds
 
  Usage     : $hit->seq_inds( seq_type, class, collapse );
@@ -2075,12 +2003,10 @@ sub seq_inds {
     $collapse ?  &Bio::Tools::Blast::HSP::collapse_nums(@inds) : @inds; 
 }
 
-
 #####################################################################################
 ##                                  INSTANCE METHODS                               ##
 #####################################################################################
 
-
 =head2 display
 
  Usage     : $sbjct_object->display( %named_parameters );
@@ -2107,7 +2033,6 @@ sub display {
     $self->show =~ /hsp/i and $self->_display_hsps( %param);
 }
 
-
 =head2 _display_stats
 
  Usage     : n/a; called automatically by display()
@@ -2159,7 +2084,6 @@ sub _display_stats {
 
 }
 
-
 =head2 _display_hsps
 
  Usage     : n/a; called automatically by display()
@@ -2200,8 +2124,6 @@ sub _display_hsps {
     }
 }
 
-
-
 =head2 homol_data
 
  Usage     : $data = $sbjct_object->homo_data( %named_params );
@@ -2328,7 +2250,6 @@ __END__
 #                                END OF CLASS                                       #
 #####################################################################################
 
-
 =head1 FOR DEVELOPERS ONLY
 
 =head2 Data Members
@@ -2393,7 +2314,6 @@ all or some of the following fields:
 		   :
  _length_aln_sbjct : Length of the aligned region of the sbjct sequence.
 
-
  INHERITED DATA MEMBERS 
  ----------------------
  _name          : From Bio::Root::Object.pm. String representing the name of the 
@@ -2402,7 +2322,6 @@ all or some of the following fields:
  _parent        : From Bio::Root::Object.pm. This member contains a reference to the
 		: Bio::Tools::Blast.pm object to which this hit belongs.
 
-
 =cut
 
 1;
