@@ -1,4 +1,3 @@
-
 #
 # BioPerl module for IUPAC
 #
@@ -89,7 +88,6 @@ the meaning shown below)
         Z        Glutamic Acid, Glutamine
         *        Terminator
 
-
         IUPAC-IUP AMINO ACID SYMBOLS:
           Biochem J. 1984 Apr 15; 219(2): 345-373
           Eur J Biochem. 1993 Apr 1; 213(1): 2
@@ -103,9 +101,9 @@ and other Bioperl modules. Send your comments and suggestions preferably
  to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-  vsns-bcd-perl@lists.uni-bielefeld.de          - General discussion
-  vsns-bcd-perl-guts@lists.uni-bielefeld.de     - Technically-oriented discussion
-  http://bio.perl.org/MailList.html             - About the mailing lists
+   bioperl-l@bioperl.org             - General discussion
+   bioperl-guts-l@bioperl.org        - Automated bug and CVS messages
+   http://bioperl.org/MailList.shtml - About the mailing lists
 
 =head2 Reporting Bugs
 
@@ -126,7 +124,6 @@ The rest of the documentation details each of the object methods. Internal metho
 
 =cut
 
-
 # Let the code begin...
 
 package Bio::Tools::IUPAC;
@@ -149,7 +146,6 @@ use Bio::Root::Object;
            Seq objects on demand.
  Args    : an ambiguously coded Seq.pm object that has a specified 'type'
 
-
 =cut
 
 # new() is inherited from Bio::Root::Object
@@ -231,7 +227,6 @@ sub _initialize {
  Returns : a Seq.pm object
  Args    : none.
 
-
 =cut
 
 sub next_seq{
