@@ -3,7 +3,7 @@
 # PURPOSE : To encapsulate commonly used URLs for web key websites in bioinformatics.
 # AUTHOR  : Steve A. Chervitz
 # CREATED : 27 Aug 1996 
-# REVISION: $Id: WWW.pm,v 1.3 2000/03/15 11:23:21 jgrg Exp $
+# REVISION: $Id: WWW.pm,v 1.3.2.1 2000/09/15 08:24:24 jgrg Exp $
 #
 # For documentation, run this module through pod2html 
 # (preferably from Perl v5.004 or better).
@@ -32,14 +32,13 @@ use vars qw(@ISA @EXPORT_OK %EXPORT_TAGS $ID $VERSION $BioWWW $Revision);
 
 $ID = 'Bio::Tools::WWW';
 $VERSION = 0.014;
-$Revision = '$Id: WWW.pm,v 1.3 2000/03/15 11:23:21 jgrg Exp $'; #'
+$Revision = '$Id: WWW.pm,v 1.3.2.1 2000/09/15 08:24:24 jgrg Exp $'; #'
 
 ## Static object.
 $BioWWW = {};
 bless $BioWWW, $ID;
 $BioWWW->{'_name'} = "Static $ID object";
 
-
 ## POD Documentation:
 
 =head1 NAME
@@ -137,9 +136,9 @@ User feedback is an integral part of the evolution of this and other Bioperl mod
 Send your comments and suggestions preferably to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-    vsns-bcd-perl@lists.uni-bielefeld.de          - General discussion
-    vsns-bcd-perl-guts@lists.uni-bielefeld.de     - Technically-oriented discussion
-    http://bio.perl.org/MailList.html             - About the mailing lists
+   bioperl-l@bioperl.org             - General discussion
+   bioperl-guts-l@bioperl.org        - Automated bug and CVS messages
+   http://bioperl.org/MailList.shtml - About the mailing lists
 
 =head2 Reporting Bugs
 
@@ -163,10 +162,8 @@ Copyright (c) 1996-98 Steve A. Chervitz. All Rights Reserved.
 This module is free software; you can redistribute it and/or 
 modify it under the same terms as Perl itself.
 
-
 =cut
 
-
 #
 ##
 ###
@@ -175,7 +172,6 @@ modify it under the same terms as Perl itself.
 ##
 #
 
-
 ############################  DATA ##################################
 
 ### Database homepage links.
@@ -230,7 +226,6 @@ my %Stem_url =
       'pir'         =>'http://www-nbrf.georgetown.edu/cgi-bin/nbrfget?',
       );
 
-
 ### Database access stems/links.
 my %Search_url = 
     ( #'3db'       =>'http://pdb.pdb.bnl.gov/cgi-bin/pdbids?3DB_ID=',   # Former stem
@@ -294,8 +289,6 @@ my %Search_url =
       'ypd'          =>'http://quest7.proteome.com/YPD/',  
       );
 
-
-
 ### CGI stems for SGD and Sacch3D.
 my %SGD_stem_url =
     ('stanford'      =>'http://genome-www.stanford.edu/',
@@ -337,7 +330,6 @@ my %SGD_url =
      'tmp'          =>$SGD_stem_url{'stanford'}.'tmp/',
      );
 
-
 ### Sacch3D stems and links.
 my %S3d_url =
     ('home'          =>$Home_url{'sacch3d'},
@@ -375,7 +367,6 @@ my %S3d_url =
      'pdb_neighbors' =>$SGD_stem_url{'s3d'}.'pdb_neighbors?id=CHAIN&gene=ORF_NAME',
      );
 
-
 ### 3D viewer stems.
 my %Viewer_url = 
 #    ('java'     =>$SGD_stem_url{'sgd'}.'Sacch3D/pdbViewer.pl?pdbCode=PDB&orf=',
@@ -389,7 +380,6 @@ my %Viewer_url =
      'kinemage' =>'http://prosci.org/Kinemage',
      );
 
-
 ### Stock HTML
 # The error reporting HTML strings represent some experiments in human psychology: 
 # how do you induce users to report errors that you should know about yet not
@@ -416,13 +406,10 @@ QQ_TECH_QQ
 
      );
 
-
 ### Miscellaneous URLs. Configure as desired for your site.
 my $Not_found_url = 'http://genome-www.stanford.edu/Sacch3D/notfound.html';
 my $Tmp_url       = 'http://genome-www.stanford.edu/tmp/';
 
-
-
 =head1 APPENDIX
 
 Methods beginning with a leading underscore are considered private
@@ -436,7 +423,6 @@ for documentation purposes only.
 ##                          ACCESSOR METHODS                            
 #########################################################################
 
-
 =head2 home_url
 
  Usage     : $BioWWW->home_url(<string>)
@@ -465,8 +451,6 @@ sub home_url {
 				$Not_found_url);
 }
 
-
-
 =head2 search_url
 
  Usage     : $BioWWW->search_url(<string>)
@@ -509,8 +493,6 @@ sub search_url {
 				$Not_found_url);
 }
 
-
-
 =head2 stem_url
 
  Usage     : $BioWWW->stem_url(<string>)
@@ -566,8 +548,6 @@ sub viewer_url {
 				$Not_found_url);
 }
 
-
-
 =head2 not_found_url
 
  Usage     : $BioWWW->not_found_url()
@@ -583,7 +563,6 @@ sub viewer_url {
 sub not_found_url {  my $self = shift; $Not_found_url; }
 #-----------------
 
-
 =head2 tmp_url
 
  Usage     : $BioWWW->tmp_url()
@@ -599,8 +578,6 @@ sub not_found_url {  my $self = shift; $Not_found_url; }
 sub tmp_url {  my $self = shift; $Tmp_url; }
 #-----------
 
-
-
 =head2 search_link
 
  Usage     : $BioWWW->search_link(<site>, <value>, <text>)
@@ -625,8 +602,6 @@ sub search_link {
     qq|<A HREF="$url$value">$text</A>|;
 }
 
-
-
 =head2 viewer_link
 
  Usage     : $BioWWW->viewer_link(<site>, <value>, <text>)
@@ -651,8 +626,6 @@ sub viewer_link {
     qq|<A HREF="$url$value">$text</A>|;
 }
 
-
-
 =head2 html
 
  Usage     : $BioWWW->html(<string>)
@@ -680,13 +653,11 @@ sub html {
     (exists $Html{$arg}) ? $Html{$arg} : "<pre>(missing HTML for \"$arg\")</pre>";
 }
 
-
 ###
 ### Below are accessors specialized for the Saccharomyces Genome Database
 ### It is possible that they will be moved to Bio::SGD::WWW.pm in the future.
 ### 
 
-
 =head2 sgd_url
 
  Usage     : $BioWWW->sgd_url(<string>)
@@ -712,8 +683,6 @@ sub sgd_url {
 				$Not_found_url);
 }
 
-
-
 =head2 s3d_url
 
  Usage     : $BioWWW->s3d_url(<string>)
@@ -739,8 +708,6 @@ sub s3d_url {
 				$Not_found_url);
 }
 
-
-
 =head2 sgd_stem_url
 
  Usage     : $BioWWW->sgd_stem_url(<string>)
@@ -766,8 +733,6 @@ sub sgd_stem_url {
 				$Not_found_url);
 }
 
-
-
 =head2 s3d_link
 
  Usage     : $BioWWW->s3d_link(<site>, <value>, <text>)
@@ -795,7 +760,6 @@ sub s3d_link {
 }
 	      
 
-
 =head2 sgd_link
 
  Usage     : $BioWWW->sgd_link(<site>, <value>, <text>)
@@ -822,7 +786,6 @@ sub sgd_link {
     qq|<A HREF="$url$value">$text</A>|;
 }
 
-
 #########################################################################
 ##                        INSTANCE METHODS                              
 #########################################################################
@@ -855,7 +818,6 @@ sub start_html {
     }
 }
 
-
 =head2 redirect
 
  Usage     : $BioWWW->redirect(<string>)
@@ -876,8 +838,6 @@ sub redirect {
     print "Content-type: text/html\n\n"; 
 }
 
-
-
 =head2 pre
 
  Usage     : $BioWWW->pre("text to be pre-formatted");
@@ -896,7 +856,6 @@ sub pre {
     "<PRE>\n".shift()."\n</PRE>";
 }
 
-
 #----------------
 sub html_footer {
 #----------------
@@ -927,7 +886,6 @@ $modified
 HTML
 }
 
-
 =head2 strip_html
 
  Usage     : $boolean = &strip_html( string_ref, [fast] );
@@ -1002,7 +960,6 @@ sub strip_html {
     $stripped;
 }
 
-
 1;
 __END__
 
@@ -1022,9 +979,7 @@ all or some of the following fields:
  _started_html   Defined the on the initial invocation of start_html()
                  to avoid duplicate printing out the "Content-type..." header.
 
-
 =cut
 
 1;
 
-
