@@ -1,4 +1,3 @@
-## $Id: pSW.pm,v 1.3 1999/04/06 15:52:19 birney Exp $
 
 #
 # BioPerl module for Bio::Tools::pSW
@@ -43,14 +42,14 @@ Follow the installation instructions included in the README file.
 
 =head1 DESCRIPTION
 
-pSW is an Alignment Factory. It builds pairwise alignments using the smith
-waterman algorithm. The alignment algorithm is implemented in C and
-added in using an XS extension. The XS extension basically comes from the
-Wise2 package, but has been slimmed down to only be the alignment part
-of that (this is a good thing!). The XS extension comes from the bp_sw
-package which is found in Bio/Compile/SW in the bioperl distriubition.
-I<Warning> This package will not work if you have not compiled the 
-Bio/Compile/SW package.
+pSW is an Alignment Factory. It builds pairwise alignments using the
+smith waterman algorithm. The alignment algorithm is implemented in C
+and added in using an XS extension. The XS extension basically comes
+from the Wise2 package, but has been slimmed down to only be the
+alignment part of that (this is a good thing!). The XS extension comes
+from the bioperl-ext package which is distributed along with bioperl.
+I<Warning> This package will not work if you have not compiled the
+bioperl-ext package.
 
 The mixture of C and Perl is ideal for this sort of 
 problem. Here are some plus points for this strategy: 
@@ -87,9 +86,9 @@ User feedback is an integral part of the evolution of this and other Bioperl mod
 Send your comments and suggestions preferably to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-    vsns-bcd-perl@lists.uni-bielefeld.de          - General discussion
-    vsns-bcd-perl-guts@lists.uni-bielefeld.de     - Technically-oriented discussion
-    http://bio.perl.org/MailList.html             - About the mailing lists
+   bioperl-l@bioperl.org             - General discussion
+   bioperl-guts-l@bioperl.org        - Automated bug and CVS messages
+   http://bioperl.org/MailList.shtml - About the mailing lists
 
 =head2 Reporting Bugs
 
@@ -109,32 +108,28 @@ The rest of the documentation details each of the object methods. Internal metho
 
 =cut
 
-
 # Let the code begin...
 
-
 package Bio::Tools::pSW;
-use vars qw($AUTOLOAD @ISA);
+use vars qw(@ISA);
 use strict;
 no strict ( 'refs');
 
 use Bio::Tools::AlignFactory;
 use Bio::SimpleAlign;
 
-
-@ISA = qw(Bio::Tools::AlignFactory Exporter);
+@ISA = qw(Bio::Tools::AlignFactory);
 
 BEGIN {
     eval {
-	require bp_sw;
+	require Bio::Ext::Align;
     };
     if ( $@ ) {
-	print STDERR ("\nThe C-compiled engine for Smith Waterman alignments (bp_sw) has not been installed.\n Please read the installation instructions for bioperl for using the compiled extensions\n\n");
+	print STDERR ("\nThe C-compiled engine for Smith Waterman alignments (Bio::Ext::Align) has not been installed.\n Please read the install the bioperl-ext package\n\n");
 	exit(1);
     }
 }
 
-
 # new() is inherited from Bio::Root::Object
 
 # _initialize is where the heavy stuff will happen when new is called
@@ -142,8 +137,6 @@ BEGIN {
 sub _initialize {
   my($self,@p) = @_;
 
-
-
   my($matrix,$gap,$ext) = $self->_rearrange([qw(MATRIX
 						GAP
 						EXT
@@ -176,7 +169,6 @@ sub _initialize {
   return $make; # success - we hope!
 }
 
-
 =head2 pairwise_alignment
 
  Title   : pairwise_alignment
@@ -185,7 +177,6 @@ sub _initialize {
  Returns : A SimpleAlign object
  Args    :
 
-
 =cut
 
 sub pairwise_alignment{
@@ -195,14 +186,13 @@ sub pairwise_alignment{
     $self->set_memory_and_report();
     # create engine objects 
 
-    $t1  = &bp_sw::new_Sequence_from_strings($seq1->id(),$seq1->str());
-    $t2  = &bp_sw::new_Sequence_from_strings($seq2->id(),$seq2->str());
-    $aln = &bp_sw::Align_Sequences_ProteinSmithWaterman($t1,$t2,$self->{'matrix'},-$self->gap,-$self->ext);
+    $t1  = &Bio::Ext::Align::new_Sequence_from_strings($seq1->id(),$seq1->seq());
+    $t2  = &Bio::Ext::Align::new_Sequence_from_strings($seq2->id(),$seq2->seq());
+    $aln = &Bio::Ext::Align::Align_Sequences_ProteinSmithWaterman($t1,$t2,$self->{'matrix'},-$self->gap,-$self->ext);
     if( ! defined $aln || $aln == 0 ) {
 	$self->throw("Unable to build an alignment");
     }
 
-
     # free sequence engine objects
 
     $t1 = $t2 = 0;
@@ -212,8 +202,8 @@ sub pairwise_alignment{
 
     # we are going to need the sequences as arrays for convience
 
-    @str1 = $seq1->seq();
-    @str2 = $seq2->seq();
+    @str1 = split(//, $seq1->seq());
+    @str2 = split(//, $seq2->seq());
 
     # get out start points
 
@@ -262,17 +252,17 @@ sub pairwise_alignment{
 
     $tstr = join('',@ostr1);
     $tid = $seq1->id();
-    $out->addSeq(Bio::Seq->new( -seq=> $tstr,
-			       -start => $start1,
-			       -end   => $end1,
-			       -id=>$tid ));
+    $out->addSeq(Bio::LocatableSeq->new( -seq=> $tstr,
+					 -start => $start1,
+					 -end   => $end1,
+					 -id=>$tid ));
 
     $tstr = join('',@ostr2);
     $tid = $seq2->id();
-    $out->addSeq(Bio::Seq->new( -seq=> $tstr,
-			       -start => $start2,
-			       -end => $end2,
-			       -id=> $tid ));
+    $out->addSeq(Bio::LocatableSeq->new( -seq=> $tstr,
+					 -start => $start2,
+					 -end => $end2,
+					 -id=> $tid ));
 
     # give'm back the alignment
 
@@ -292,15 +282,15 @@ sub align_and_show {
 
     $self->set_memory_and_report();
 
-    $t1  = &bp_sw::new_Sequence_from_strings($seq1->id(),$seq1->str());
+    $t1  = &Bio::Ext::Align::new_Sequence_from_strings($seq1->id(),$seq1->seq());
 
-    $t2  = &bp_sw::new_Sequence_from_strings($seq2->id(),$seq2->str());
-    $aln = &bp_sw::Align_Sequences_ProteinSmithWaterman($t1,$t2,$self->{'matrix'},-$self->gap,-$self->ext);
+    $t2  = &Bio::Ext::Align::new_Sequence_from_strings($seq2->id(),$seq2->seq());
+    $aln = &Bio::Ext::Align::Align_Sequences_ProteinSmithWaterman($t1,$t2,$self->{'matrix'},-$self->gap,-$self->ext);
     if( ! defined $aln || $aln == 0 ) {
 	$self->throw("Unable to build an alignment");
     }
 
-    &bp_sw::write_pretty_seq_align($aln,$t1,$t2,12,50,$fh);
+    &Bio::Ext::Align::write_pretty_seq_align($aln,$t1,$t2,12,50,$fh);
 
 }
 
@@ -325,7 +315,7 @@ sub matrix {
 
     # talking to the engine here...
 
-    $temp = &bp_sw::CompMat::read_Blast_file_CompMat($comp);
+    $temp = &Bio::Ext::Align::CompMat::read_Blast_file_CompMat($comp);
 
     if( !(defined $temp) || $temp == 0 ) {
 	$self->throw("$comp cannot be read as a BLAST comparison matrix file");
@@ -334,8 +324,6 @@ sub matrix {
     $self->{'matrix'} = $temp;
 }
 
-
-
 =head2 gap
 
  Title     : gap
@@ -361,7 +349,6 @@ sub gap {
     return $self->{'gap'};
 }
 
-
 =head2 ext
 
  Title     : ext
@@ -387,3 +374,4 @@ sub ext {
 }
 
     
+
