@@ -25,9 +25,9 @@
   (insert "=head1 DESCRIPTION\n\nDescribe the object here\n\n")
   (insert "=head1 FEEDBACK\n\n=head2 Mailing Lists\n\n")
   (insert "User feedback is an integral part of the evolution of this\nand other Bioperl modules. Send your comments and suggestions preferably\n to one of the Bioperl mailing lists.\nYour participation is much appreciated.\n\n")
-  (insert "  vsns-bcd-perl@lists.uni-bielefeld.de          - General discussion\n  vsns-bcd-perl-guts@lists.uni-bielefeld.de     - Technically-oriented discussion\n  http://bio.perl.org/MailList.html             - About the mailing lists\n\n")
+  (insert "  bioperl-l@bioperl.org          - General discussion\n  bioperl-guts-l@bioperl.org     - Technically-oriented discussion\n  http://bioperl.org/MailList.shtml             - About the mailing lists\n\n")
   (insert "=head2 Reporting Bugs\n\nReport bugs to the Bioperl bug tracking system to help us keep track\n the bugs and their resolution.\n Bug reports can be submitted via email or the web:\n\n")
-  (insert "  bioperl-bugs@bio.perl.org\n  http://bio.perl.org/bioperl-bugs/\n\n")
+  (insert "  bioperl-bugs@bioperl.org\n  http://bioperl.org/bioperl-bugs/\n\n")
   (insert "=head1 AUTHOR - " perl-caretaker-name "\n\nEmail " caretaker-email "\n\nDescribe contact details here\n\n")
   (insert "=head1 APPENDIX\n\nThe rest of the documentation details each of the object methods. Internal methods are usually preceded with a _\n\n=cut\n\n")
   (insert "\n# Let the code begin...\n\n")
