@@ -1,5 +1,6 @@
 #!/usr/local/bin/perl
 
+## $Id: bpfetch.pl,v 1.8.8.2 2000/09/23 21:26:11 dag Exp $
 
 =head1 NAME
 
@@ -9,9 +10,9 @@ bpfetch.pl - fetches sequences from bioperl indexed databases
 
   bpfetch.pl swiss:ROA1_HUMAN
 
-  bpfetch.pl net::genbank:X47072
+  bpfetch.pl net::genbank:D87434
 
-  bpfetch.pl net::genpept:ROA1_HUMAN
+  bpfetch.pl net::genpept:Y247_HUMAN
 
   bpfetch.pl ace::myserver.somewhere.edu,21000:X56676
 
@@ -101,9 +102,10 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules.  Send your comments and suggestions preferably to one
 of the Bioperl mailing lists.  Your participation is much appreciated.
 
-    vsns-bcd-perl@lists.uni-bielefeld.de          - General discussion
-    vsns-bcd-perl-guts@lists.uni-bielefeld.de     - Technically-oriented discussion
-    http://bio.perl.org/MailList.html             - About the mailing lists
+  bioperl-l@bioperl.org      - General discussion
+  bioperl-guts-l@bioperl.org - Technical discussions, bug reports & CVS notices
+  
+  http://bioperl.org/MailList.shtml - About the mailing lists
 
 =head2 Reporting Bugs
 
@@ -111,8 +113,8 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution. Bug reports can be submitted via email
 or the web:
 
-    bioperl-bugs@bio.perl.org                   
-    http://bio.perl.org/bioperl-bugs/           
+    bioperl-bugs@bioperl.org                   
+    http://bioperl.org/bioperl-bugs/           
 
 =head1 AUTHOR
 
@@ -150,7 +152,7 @@ BEGIN {
             require Bio::SeqIO;
 	};
 	if ( $@ ) {
-	    print STDERR ("\nbpindex cannot find Bio::Index::Fasta and Bio::Index::EMBL\nbpindex needs to have bioperl installed for it to run.\nBioperl is very easy to install\nSee http://bio.perl.org for more information\n\n");
+	    print STDERR ("\nbpindex cannot find Bio::Index::Fasta and Bio::Index::EMBL\nbpindex needs to have bioperl installed for it to run.\nBioperl is very easy to install\nSee http://bioperl.org for more information\n\n");
 	    exit(1);
 	} else {
 	    print STDERR ("\nYou are running bpindex.pl without installing bioperl.\nYou have done it from bioperl/scripts, and so we can find the necessary information\nbut it is much better to install bioperl\n\nPlease read the README in the bioperl distribution\n\n");
